@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Panel Profiles
 #   Copyright (C) 2013 Alistair Buxton <a.j.buxton@gmail.com>
-#   Copyright (C) 2015-2020 Sean Davis <bluesabre@xfce.org>
+#   Copyright (C) 2015-2021 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 3 or newer,
@@ -32,11 +32,21 @@ import warnings
 
 import gi
 gi.require_version('Gtk', '3.0')
+# Try to import the new Libxfce4ui gir name (since 4.15.7)
+# if it does not exists, try the old libxfce4ui
+try:
+  gi.require_version('Libxfce4ui', '2.0')
+  from gi.repository import Libxfce4ui as libxfce4ui
+except ValueError:
+  gi.require_version('libxfce4ui', '2.0')
+  from gi.repository import libxfce4ui
 
 from gi.repository import Gtk, GLib, Gio
 
 from panelconfig import PanelConfig
 
+import info
+
 warnings.filterwarnings("ignore")
 
 homedir = GLib.get_home_dir()
@@ -48,8 +58,15 @@ class XfcePanelProfiles:
     data_dir = "xfce4-panel-profiles"
     save_location = os.path.join(GLib.get_user_data_dir(), data_dir)
 
-    def __init__(self):
-        '''Initialize the Panel Profiles application.'''
+    def __init__(self, from_panel=False):
+        '''Initialize the Panel Profiles application.
+
+        If 'from_panel' is set to 'True' the application launches 'xfce4-panel
+        --preferences' when the user closes this application.
+        '''
+        # Temporary fix: https://stackoverflow.com/a/44230815
+        _ = libxfce4ui.TitledDialog()
+
         self.builder = Gtk.Builder()
         self.builder.set_translation_domain('xfce4-panel-profiles')
 
@@ -59,8 +76,6 @@ class XfcePanelProfiles:
         self.builder.connect_signals(self)
 
         self.window = self.builder.get_object("xfpanel_switch_window")
-        self.window.set_title(_("Panel Profiles"))
-        self.fix_xfce_header()
 
         self.load_xfconf()
 
@@ -81,6 +96,8 @@ class XfcePanelProfiles:
         if not os.path.exists(self.save_location):
             os.makedirs(self.save_location)
 
+        self.from_panel = from_panel
+
         self.window.show()
 
     def _copy(self, src, dst):
@@ -123,17 +140,6 @@ class XfcePanelProfiles:
             interface,
             cancellable)
 
-    def fix_xfce_header(self):
-        ''' Set background-color of frame to base-color to make it resemble the
-        XfceHeading widget '''
-        self.xfce_header = self.builder.get_object("xfce_header")
-        entry = Gtk.Entry.new()
-        style = entry.get_style_context()
-        base_color = style.lookup_color("theme_base_color")
-        self.xfce_header.override_background_color(0, base_color[1])
-        fg_color = style.lookup_color("theme_fg_color")
-        self.xfce_header.override_color(0, fg_color[1])
-
     def get_data_dirs(self):
         dirs = []
         for directory in GLib.get_system_data_dirs():
@@ -305,14 +311,25 @@ class XfcePanelProfiles:
         Gtk.main_quit()
 
     def on_close_clicked(self, *args):
-        '''Exit the application when the window is closed.'''
+        '''
+        Exit the application when the window is closed. Optionally launch
+        'xfce4-panel --preferences' if the application is launched with
+        '--from-profile' option.
+        '''
+        if self.from_panel:
+            path = GLib.find_program_in_path('xfce4-panel')
+
+            if path != None:
+                GLib.spawn_command_line_async(path + ' --preferences')
+
         Gtk.main_quit()
 
     def on_help_clicked(self, *args):
-        '''Navigate to the application documentation on Help click.'''
-        screen = self.window.get_screen()
-        link = "https://docs.xfce.org/apps/xfce4-panel-profiles/start"
-        Gtk.show_uri(screen, link, Gtk.get_current_event_time())
+        '''Shows Xfce's standard help dialog.'''
+        libxfce4ui.dialog_show_help(parent=self.window,
+                                    component='xfce4-panel-profiles',
+                                    page='xfce4-panel-profiles',
+                                    offset=None)
 
 
 class PanelSaveDialog(Gtk.MessageDialog):
@@ -382,6 +399,8 @@ class PanelConfirmDialog(Gtk.MessageDialog):
         box.show_all()
 
 if __name__ == "__main__":
+    from_panel = False
+
     import sys
 
     session_bus = Gio.BusType.SESSION
@@ -414,13 +433,22 @@ if __name__ == "__main__":
                 print(repr(e))
                 exit(1)
             exit(0)
+        elif sys.argv[1] == '--version':
+            print(info.appname + ' ' + info.version)
+            exit(0)
+        elif sys.argv[1] == '--from-panel':
+            from_panel = True
         else:
             print('Xfce Panel Profiles - Usage:')
-            print(sys.argv[0] + ' : load graphical user interface.')
-            print(sys.argv[0] + ' save <filename> : save current configuration.')
-            print(sys.argv[0] + ' load <filename> : load configuration from file.')
+            print(info.appname + ' : load graphical user interface.')
+            print(info.appname + ' save <filename> : save current configuration.')
+            print(info.appname + ' load <filename> : load configuration from file.')
             print('')
             exit(-1)
 
-    main = XfcePanelProfiles()
-    Gtk.main()
+    main = XfcePanelProfiles(from_panel)
+
+    try:
+        Gtk.main()
+    except KeyboardInterrupt:
+        pass
